/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2009 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 *
 *******************************************************************************
 *
 * $Id: MetadataItemInterceptor.java,v d60681e7fc1d 2009/09/17 23:59:23 fabrizio $
 *
 ******************************************************************************/
package it.tidalwave.metadata.spi;

import it.tidalwave.metadata.Metadata;
import it.tidalwave.metadata.MetadataItemHolder;
import javax.annotation.Nonnull;

/*******************************************************************************
 *
 * This class makes it possible for service providers to intercept the creation
 * of a new metadata item (so, for instance, it can be managed by a persistence
 * service or similar). Implementations just need to register through the
 * <code>META-INF/services</code> mechanism. Each interceptor must declare the
 * class of the items that it is able to manage.
 *
 * note       Notifies Items life cycle
 * @stereotype listener
 *
 * @author  Fabrizio Giudici
 * @version $Id: MetadataItemInterceptor.java,v d60681e7fc1d 2009/09/17 23:59:23 fabrizio $
 *
 ******************************************************************************/
public interface MetadataItemInterceptor<Item>
  {
    /***************************************************************************
     *
     * Returns the class of the items that this interceptor is willing to manage.
     * 
     * @return   the managed class
     * 
     **************************************************************************/
    @Nonnull 
    public Class<Item> getItemClass();
    
    /***************************************************************************
     *
     * Notifies that a certain metadata item has been created.
     * 
     * @param  metadata      the {@link Metadata} owning the item
     * @param  holder        the holder of the metadata item
     * 
     **************************************************************************/
    public void notifyItemCreated (@Nonnull Metadata metadata, @Nonnull MetadataItemHolder<Item> holder)
      throws Exception;

    // There's no notifyItemRemoved() since metadata items are never removed;
    // eventually, they just become empty. 
  }  
